# This Build.PL for Dist-Zilla-Plugin-GenerateFile-FromShareDir was generated by Dist::Zilla::Plugin::ModuleBuildTiny 0.020.
use strict;
use warnings;


use 5.008;
use Module::Build::Tiny 0.034;
Build_PL();

